*!*	<pdm>
*!*	 <descr>
NOTE  <p>This is description of "main", first paragraph</p>
NOTE  <p>This is description of "main", second paragraph
NOTE  with Expression <expr>Procedure</expr> and a second Expression <expr>DO ..WHILE</expr></p>
NOTE  </descr>
*!* </pdm>


#IF VERSION(5)<7 THEN
PROCEDURE STREXTRACT
*!*	<pdm>
*!*	 <descr>
NOTE  This function emulates VFP <expr>STREXTRACT</expr> for versions below VFP 7.0</descr>
*!*	DESCR The function will be disabled in Version 7 and beyond using #IF
*!*	 <Example><code>
*!*	TEXT lcText NOSHOW
*!*	<short>Specify the type of controls <i>placed</i> on the search.</short>
*!*	ENDTEXT
*!*	lcExmaple = STREXTRACT(lcText,"<i>","</i>") &&returns placed
*!*	 </code></Example>
*!*	 PARAMS tcSearchExpression ByVal In Character Specifies the string to search.
*!*	 <params name="tcBeginDelim" type="Character" dir="In">
*!*	  <short>Specifies the character that delimits the beginning of cSearchExpression.</short>
*!*	 </params>
*!*	 <params name="tcEndDelim" type="Character" dir="In" inb="1">
*!*	  <short>Specifies the character that delimits the end of cSearchExpression.</short>
*!*	 </params>
*!*	 <params name="tnOccurrence" type="Integer" dir="in" inb="1">
*!*	  <short>Specifies at which occurrence of cBeginDelim in cSearchExpression to start the extraction.</short>
*!*	 </params>
*!*	 <params name="tnFlag" type="Integer" dir="In" inb="1" outb="2">
*!*	  <short>Specify the type of controls placed on the search.</short>
*!*	  <detail>
*!*	<xhtml>
*!*	   Specify the type of controls placed on the search. The number you specify in nFlag provides a bit-value that determines options according to the following table:
*!*	<table cellspacing="0" border="1">
*!*	 <colgroup>
*!*	  <col width="11%"/>
*!*	  <col width="89%"/>
*!*	 </colgroup>
*!*	 <thead valign="top">
*!*	  <th>Bit</th>
*!*	  <th>Description</th>
*!*	 </thead>
*!*	 <tr valign="top">
*!*	  <td>1</td>
*!*	  <td>
*!*	   Case-insensitive search
*!*	  </td>
*!*	 </tr>
*!*	 <tr valign="top">
*!*	  <td>2</td>
*!*	  <td>
*<dl><dt>
*!*	   End delimiter not required. Specifies that a search, which finds no occurrence of <I>cEndDelim,</I> returns the contents of <I>cSearchExpression </I>from the <I>cBeginDelim</I> location.
*</dt></dl>
*!*	  </td>
*!*	 </tr>
*!*	</table>
*!*	</xhtml>
*!*	  </detail>
*!*	 </params>
*!*	 <copyright><xhtml>
*!*	  &copy; <em>1992 - 2003 Microsoft Corporation. All rights reserved.</em><br />
*!*	  As an example for PDM by Agnes die Beste
*!*	 </xhtml></copyright>
*!*	 <retval type="Character">Returns the string extracted</RETVAL>
*!*	 <remarks>The default is a case sensitive search in which delimiters must be found (no nFlag value).
*!*	 If cBeginDelim is an empty string, the search is conducted from the beginning of cSearchExpression to the first occurrence of cEndDelim. If cEndDelim is an empty string STREXTRACT( ) returns a string from nOccurrence of cBeginDelim to the end of cSearchExpression.
*!*	Note that the code in source code need to be wraped like
*!*	<code>
*!*	#IF VERSION(5)<700 THEN
*!*	* source code
*!*	#ENDIF &&VERSION(5)<700</code>
*!*	</remarks>
*!* </pdm>
 PARAMETERS;
  tcSearchExpression,;
  tcBeginDelim,;
  tcEndDelim,;
  tnOccurrence,;
  tnFlag
  
 LOCAL;
  lnStart,;
  lnEnd,;
  llAllCase,;
  llToEnd

 STORE 0 TO;
  lnStart,;
  lnEnd
 IF EMPTY(tnOccurrence) THEN
  tnOccurrence = 1				&&Standard
 ENDIF &&EMPTY(tnOccurrence)

 IF EMPTY(tnFlag) THEN
  tnFlag = 0					&&Standard
 ENDIF &&EMPTY(tnFlag)
 IF BITAND(tnFlag,1)=1 THEN
  llAllCase = .T.				&&Do not match case
 ENDIF &&BITAND(tnFlag,1)=1
 IF BITAND(tnFlag,2)=2 THEN
  llToEnd = .T.					&&If end not found, use end of string
 ENDIF &&BITAND(tnFlag,2)=2

 DO CASE
  CASE EMPTY(tcBeginDelim)
   lnStart      = 1
  CASE llAllCase
   lnStart = ATC(tcBeginDelim,tcSearchExpression,tnOccurrence)
  OTHERWISE
   lnStart = AT (tcBeginDelim,tcSearchExpression,tnOccurrence)
 ENDCASE

 IF !EMPTY(lnStart) THEN
  tcSearchExpression = SUBSTR(tcSearchExpression,lnStart+LEN(tcBeginDelim))
  DO CASE
   CASE EMPTY(tcEndDelim)		&&No end defined, get all to end
    lnEnd      = LEN(tcSearchExpression)+1
   CASE llAllCase
    lnEnd = ATC(tcEndDelim,tcSearchExpression,tnOccurrence)
   OTHERWISE
    lnEnd = AT (tcEndDelim,tcSearchExpression,tnOccurrence)
  ENDCASE
  IF EMPTY(lnEnd) AND llToEnd THEN
   lnEnd = LEN(tcSearchExpression)+1
  ENDIF &&EMPTY(lnEnd)   ...
 ENDIF &&!EMPTY(lnStart)

 RETURN SUBSTR(tcSearchExpression,1,lnEnd-1)
ENDPROC &&STREXTRACT
#ENDIF &&VERSION(5)<7


DEFINE Class _AB_TEST AS Custom

*!*	<pdm>
*!*	 <descr>
*!*	 Detail description about class _AB_TEST_1 </descr>
*!* </pdm>

   Name="_AB_TEST"

ENDDEFINE

DEFINE Class _AB_TEST_1 AS Custom

*!*	<pdm>
*!*	 <descr>
*!*	 Detail description about class _AB_TEST_1 </descr>
*!* </pdm>

   Name="_AB_TEST_1"

   PROCEDURE Test(laCol, loArray, lii)
*!*	<pdm>
*!*	<!-- <descr></descr> -->
*!*	<params name="laCol" type="Array" byref="0" dir="" inb="0" outb="0">
*!*	<short></short>
*!*	<detail></detail>
*!*	</params>
*!*	<params name="loArray" type="Object" byref="0" dir="" inb="0" outb="0">
*!*	<short></short>
*!*	<detail></detail>
*!*	</params>
*!*	<params name="lii" type="Integer" byref="0" dir="" inb="0" outb="0">
*!*	<short></short>
*!*	<detail></detail>
*!*	</params>
*!*	<comment>
*!*	<retval type=""></retval>
*!*	<remarks></remarks>
*!*	<example></example>
*!*	<seealso>
*!*	 <see loca="" class="" pem=""></see>
*!*	</seealso>
*!*	<appliesto toref="0" toalso="0" />
*!*	</comment>
*!*	<copyright><i>&copy;28.8.2004 JvP GmbH</i></copyright>
*!*	</pdm> 
   ENDPROC
ENDDEFINE


DEFINE Class _AB_TEST_2 AS Custom
   Name="_AB_TEST_2"
   

   PROCEDURE Test2(laCol,;
    loArray, lii) AS STRING
*just a comment x
   ENDPROC
   
*!*	<pdm>
*!*	 <descr>
*!*	 Detail description about class _AB_TEST_2</descr>
*!* </pdm>

   PROCEDURE Test(laCol, loArray, lii)
   ENDPROC

   
ENDDEFINE
